__all__ = 'AttributeType', 'Attribute'

import aenum
from abc import abstractmethod


class AttributeType(aenum.Enum):
    STRING = "STRING"
    ENUM = "ENUM"
    NULL = "NULL"
    BOOLEAN = "BOOLEAN"
    INTEGER = "INTEGER"


class Attribute:

    def __init__(self,
                 key,
                 display_name,
                 description,
                 attribute_type,
                 subtype_kwargs):

        self._key = key
        self._display_name = display_name
        self._description = description
        self._attribute_type = attribute_type
        self._subtype_kwargs = subtype_kwargs

    def get_key(self):
        return self._key

    def get_display_name(self):
        return self._display_name

    def get_description(self):
        return self._description

    def get_type(self):
        return self._attribute_type

    def get_subtype_kwargs(self):
        return self._subtype_kwargs

    @abstractmethod
    def get_default_value(self):
        raise NotImplementedError

    @abstractmethod
    def validate_value(self, value):
        raise NotImplementedError
