__all__ = 'ProjectAttributeInstance'

from abc import abstractmethod
from gm_meta_plugin.project_attribute import ProjectAttribute
from gm_meta_plugin.transition import Transition


class ProjectAttributeInstance(ProjectAttribute):

    def __init__(self, project_attribute):

        plugin = project_attribute.get_plugin()

        # children of the project attribute need instantiating as well
        transitions = list(map(lambda t: ProjectAttributeInstance._convert_transition(plugin, t),
                               project_attribute.get_transitions()))

        ProjectAttribute.__init__(self,
                                  plugin,
                                  project_attribute.get_id(),
                                  project_attribute.get_attribute(),
                                  transitions,
                                  project_attribute.get_compatible_job_definitions)

    @staticmethod
    def _convert_transition(plugin, transition):
        project_attribute_instance_factory = plugin.get_factory_collection().get_project_attribute_instance_factory()
        project_attribute = transition.get_project_attribute()

        project_attribute_instance = project_attribute_instance_factory.get_project_attribute_instance(project_attribute)
        transition_instance = Transition(transition.get_transition_formula(),
                                         project_attribute_instance,
                                         rejection_message=transition.get_rejection_message())
        return transition_instance

    @abstractmethod
    def get_value(self):
        raise NotImplementedError

    @abstractmethod
    def set_value(self, value):
        raise NotImplementedError

    def transition(self, input=None, force_transition=False):
        if input is None:
            input = self.get_value()

        return ProjectAttribute.transition(self, input, force_transition=force_transition)

