__all__ = 'ComboBox'

from .input_widget import InputWidget
from PySide2 import QtCore
from PySide2 import QtWidgets


class ComboBox(QtWidgets.QComboBox, InputWidget):

    def __init__(self, update_items_callback=None, parent=None):
        QtWidgets.QComboBox.__init__(self, parent=parent)
        self.update_items_callback=update_items_callback
        self.currentIndexChanged.connect(self._catch_value_change)

        # set strong focus so input does not gain focus from mouse wheel events
        self.setFocusPolicy(QtCore.Qt.StrongFocus)

    def set_update_items_callback(self, update_items_callback):
        self.update_items_callback = update_items_callback

    def update_items(self):
        if self.update_items_callback:
            self.update_items_callback()

    def get_value(self):
        return self.currentData()

    def set_value(self, value):
        index = self.findData(value)
        self.setCurrentIndex(index)

    def wheelEvent(self, event):
        if self.hasFocus():
            return QtWidgets.QComboBox.wheelEvent(self, event)
        else:
            event.ignore()
