__all__ = 'RemoteProjectContainer'

from PySide2 import QtCore
from PySide2 import QtWidgets

import gm_meta_plugin
from gm_meta_plugin.gridmarkets import constants as api_constants
from gm_qt_plugin import qt_utils
from gm_qt_plugin.widgets.qhline import QHLine


class RemoteProjectContainer(QtWidgets.QWidget, gm_meta_plugin.RemoteProjectContainer):

    def __init__(self, plugin, remote_projects, parent=None):
        QtWidgets.QWidget.__init__(self, parent=parent)
        gm_meta_plugin.RemoteProjectContainer.__init__(self, plugin, remote_projects)

        """ Create Widgets """
        self.title_label = QtWidgets.QLabel(u"Projects")
        self.title_label.setProperty("h2", True)

        self.qhline = QHLine()

        self._list = QtWidgets.QTreeWidget()
        self._list.setColumnCount(1)
        self._list.header().setStretchLastSection(False)
        self._list.header().setSectionResizeMode(0, QtWidgets.QHeaderView.Stretch)
        self._list.setHeaderHidden(True)
        self._list.setColumnWidth(0, 200)
        self._list.setRootIsDecorated(False)
        self._list.setMaximumHeight(120)

        """ Create Layouts """
        self.list_container_layout = QtWidgets.QVBoxLayout(self)
        self.list_container_layout.addWidget(self._list)

        group_box = QtWidgets.QGroupBox()
        group_box.setLayout(self.list_container_layout)

        self.title_layout = QtWidgets.QHBoxLayout()
        self.title_layout.setAlignment(QtCore.Qt.AlignLeft)
        self.title_layout.addWidget(self.title_label)

        self.layout = QtWidgets.QVBoxLayout(self)
        self.layout.setContentsMargins(0,0,0,0)
        self.layout.addLayout(self.title_layout)
        self.layout.addWidget(self.qhline)
        self.layout.addWidget(group_box)

    def append(self, remote_project, focus_new_item = True):
        gm_meta_plugin.RemoteProjectContainer.append(self, remote_project, focus_new_item = True)

        item = QtWidgets.QTreeWidgetItem(remote_project.get_name())
        item.setText(0, remote_project.get_name())
        item.setIcon(0, qt_utils.get_product_icon(remote_project.get_attribute(api_constants.API_KEYS.APP)))
        item.setData(0, QtCore.Qt.UserRole, item)

        self._list.addTopLevelItem(item)

        if focus_new_item:
            self._list.setCurrentItem(item)
