__all__ = 'JobPresetValidator'

import maya.cmds as cmds
from gm_meta_plugin.gridmarkets import constants as api_constants
from . import maya_constants

class JobPresetValidator:

    def __init__(self, plugin):
        self._plugin = plugin

    def get_plugin(self):
        return self._plugin

    def validate(self, job_preset):
        is_valid = True
        validation_message = u""

        # check the renderer attribute corresponds to a supported renderer
        try:
            job_preset_attribute = job_preset.get_job_preset_attribute_by_key(api_constants.API_KEYS.RENDERER)
            if job_preset_attribute.get_value().startswith(maya_constants.UNSUPPORTED_RENDERER):
                current_renderer = cmds.getAttr("defaultRenderGlobals.currentRenderer")
                is_valid = False
                validation_message = u"Renderer " + current_renderer + u" is not supported."
        except ValueError as e:
            pass

        # default comment if none passed
        job_name_attribute = job_preset.get_job_preset_attribute_by_key(api_constants.API_KEYS.JOB_NAME)
        if not job_name_attribute.get_value():
            job_name_attribute.set_value("No Comment")

        return is_valid, validation_message
