__all__ = 'MayaSceneExporter'

import pathlib
import gm_meta_plugin
import tempfile
import maya.cmds
from maya.app.general.zipScene import zipScene
from maya_utils import get_maya_scene_name
from .maya_file_packer import MayaFilePacker


class MayaSceneExporter(gm_meta_plugin.SceneExporter):

    @staticmethod
    def _save_scene_to_file(target):
        from .plugin_fetcher import PluginFetcher
        log = PluginFetcher.get_plugin().get_logging_coordinator().get_logger(__name__)
        log.info(u"Saving scene to temporary file: " + target)

        maya.cmds.file(rename=unicode(target))
        maya.cmds.file(save=True, type='mayaBinary')


    def export(self, output_dir):
        tmp_dir = tempfile.mkdtemp(prefix='gm-temp-dir-')

        scene_name = get_maya_scene_name()
        if not scene_name:
            scene_name = "maya_exported_scenem.mb"

        file_path = pathlib.Path(tmp_dir) / scene_name

        MayaSceneExporter._save_scene_to_file(unicode(file_path))

        zipScene(True)

        import zipfile
        with zipfile.ZipFile(unicode(file_path.with_suffix(file_path.suffix + '.zip')), 'r') as zip_ref:
            zip_ref.extractall(unicode(output_dir))

        #packed_project = MayaFilePacker().pack(file_path, output_dir)

        # delete temporary pre-packed .blend file
        #tmp_dir.cleanup()

        #return packed_project
